@@ -1,5 +1,4 @@
-"""
-A simple setup script to create an executable using PyQt6-WebEngine.
+"""A simple setup script to create an executable using PyQt6-WebEngine.
 This also demonstrates how to use excludes to get minimal package size.
 
 Run the build process by running the command 'python setup.py build'
@@ -20,23 +19,9 @@ except ImportError:
 include_files = []
 if get_qt_plugins_paths:
     # Inclusion of extra plugins (since cx_Freeze 6.8b2)
-    # cx_Freeze imports automatically the following plugins depending of the
-    # use of some modules:
-    # imageformats, platforms, platformthemes, styles - QtGui
-    # mediaservice - QtMultimedia
-    # printsupport - QtPrintSupport
-    for plugin_name in (
-        # "accessible",
-        # "iconengines",
-        # "platforminputcontexts",
-        # "xcbglintegrations",
-        # "egldeviceintegrations",
-        "wayland-decoration-client",
-        "wayland-graphics-integration-client",
-        # "wayland-graphics-integration-server",
-        "wayland-shell-integration",
-    ):
-        include_files += get_qt_plugins_paths("PyQt6", plugin_name)
+    # cx_Freeze automatically imports the following plugins depending on the
+    # module used, but suppose we need the following:
+    include_files += get_qt_plugins_paths("PyQt6", "multimedia")
 
 build_exe_options = {
     "bin_excludes": ["libqpdf.so", "libqpdf.dylib"],
@@ -54,7 +39,7 @@ executables = [
 
 setup(
     name="simplebrowser",
-    version="0.1",
+    version="0.2",
     description="Sample cx_Freeze PyQt6 simplebrowser script",
     options={"build_exe": build_exe_options},
     executables=executables,
